@@ -1,13 +1,12 @@
 #!/usr/bin/env python
 #
 # @package      hubzero-submit-distributor
-# @file         BatchMonitors/monitorLL.py
-# @author       Steve Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
+# @file         monitorLL.py
+# @author       Steven Clark <clarks@purdue.edu>
+# @copyright    Copyright (c) 2004-2012 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2004-2011 Purdue University
-# All rights reserved.
+# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -25,7 +24,7 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-# HUBzero is a registered trademark of Purdue University.
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
 #
 # ----------------------------------------------------------------------
 #  monitorLL.py
@@ -35,7 +34,7 @@
 import sys
 import os
 import select
-import popen2
+import subprocess
 import re
 import signal
 
@@ -183,19 +182,23 @@ class QueueMonitor:
 
    def executeQstatCommand(self,
                            command):
-      child = popen2.Popen3(command,1)
-      child.tochild.close() # don't need to talk to child
-      childout = child.fromchild
+      child = subprocess.Popen(command,shell=True,bufsize=self.bufferSize,
+                               stdout=subprocess.PIPE,
+                               stderr=subprocess.PIPE,
+                               close_fds=True)
+      childPid   = child.pid
+      childout   = child.stdout
       childoutFd = childout.fileno()
-      childerr = child.childerr
+      childerr   = child.stderr
       childerrFd = childerr.fileno()
 
-      outEOF = errEOF = 0
+      outEOF = False
+      errEOF = False
 
       outData = []
       errData = []
 
-      while 1:
+      while True:
          toCheck = []
          if not outEOF:
             toCheck.append(childoutFd)
@@ -205,13 +208,13 @@ class QueueMonitor:
          if childoutFd in ready[0]:
             outChunk = os.read(childoutFd,self.bufferSize)
             if outChunk == '':
-               outEOF = 1
+               outEOF = True
             outData.append(outChunk)
 
          if childerrFd in ready[0]:
             errChunk = os.read(childerrFd,self.bufferSize)
             if errChunk == '':
-               errEOF = 1
+               errEOF = True
             errData.append(errChunk)
 
          if len(ready[0]) == 0:
@@ -220,12 +223,13 @@ class QueueMonitor:
          if outEOF and errEOF:
             break
 
-      err = child.wait()
+      pid,err = os.waitpid(childPid,0)
       if err != 0:
          if os.WIFSIGNALED(err):
             log("%s failed w/ exit code %d signal %d" % (command,os.WEXITSTATUS(err),os.WTERMSIG(err)))
          else:
-            err = os.WEXITSTATUS(err)
+            if os.WIFEXITED(err):
+               err = os.WEXITSTATUS(err)
             log("%s failed w/ exit code %d" % (command,err))
          log("%s" % ("".join(errData)))
 
@@ -416,3 +420,4 @@ if __name__ == '__main__':
    __queueMonitor__.saveHistory()
    __queueMonitor__.monitorQ()
 
+
