@@ -1,32 +1,4 @@
 #!/usr/bin/env python
-#
-# @package      hubzero-submit-distributor
-# @file         distributor.py
-# @author       Steve Clark <clarks@purdue.edu>
-# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
-# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
-#
-# Copyright (c) 2004-2011 Purdue University
-# All rights reserved.
-#
-# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
-#
-# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
-# software: you can redistribute it and/or modify it under the terms of
-# the GNU Lesser General Public License as published by the Free Software
-# Foundation, either version 3 of the License, or (at your option) any
-# later version.
-#
-# HUBzero is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-#
-# HUBzero is a registered trademark of Purdue University.
-#
 """Distribute computation jobs to remote resources
  
    Generate a pair of script files for remote job submission.
@@ -61,23 +33,48 @@
   pressed    submitted               in                                   out
 
    """
+#
+# @package      hubzero-submit-distributor
+# @file         distributor.py
+# @author       Steven Clark <clarks@purdue.edu>
+# @copyright    Copyright 2004-2011 Purdue University. All rights reserved.
+# @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
+#
+# Copyright (c) 2004-2012 HUBzero Foundation, LLC.
+#
+# This file is part of: The HUBzero(R) Platform for Scientific Collaboration
+#
+# The HUBzero(R) Platform for Scientific Collaboration (HUBzero) is free
+# software: you can redistribute it and/or modify it under the terms of
+# the GNU Lesser General Public License as published by the Free Software
+# Foundation, either version 3 of the License, or (at your option) any
+# later version.
+#
+# HUBzero is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU Lesser General Public License for more details.
+#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+#
+# HUBzero is a registered trademark of HUBzero Foundation, LLC.
+#
 import os
 import sys
 
-from JobDistributor import JobDistributor
+from hubzero.submit.JobDistributor import JobDistributor
 
 VERSION            = 'current'
 INSTALLEDDIRECTORY = os.path.join(os.sep,'opt','submit')
 LOGDIRECTORY       = os.path.join(os.sep,'var','log','submit','distributor')
 
-RUNJOB_ROOT   = ""
-CONDOR_ROOT   = ""
-CONDOR_CONFIG = ""
+RUNJOB_ROOT   = "REMOTE"
+CONDOR_ROOT   = os.path.join(os.sep,'var','condor','Condor','7.6.6')
+CONDOR_CONFIG = os.path.join(os.sep,'var','condor','Grid','etc','condor_config')
 PBS_ROOT      = ""
 
-CHECKQUOTA = True
-
-ALLOWEDVENUEMECHANISMS = ['ssh']
+ALLOWEDVENUEMECHANISMS = ['local']
 
 JOBMONITORHOST    = ""
 JOBMONITORPORT    = 5727
@@ -85,13 +82,15 @@ PROBEMONITORHOST  = ""
 PROBEMONITORPORT  = 5728
 TUNNELMONITORHOST = ""
 TUNNELMONITORPORT = 5729
+CLOUDMONITORHOST  = ""
+CLOUDMONITORPORT  = 5726
 
 if __name__ == '__main__':
    __jobDistributor__ = JobDistributor(VERSION,INSTALLEDDIRECTORY,LOGDIRECTORY, \
-                                       CHECKQUOTA, \
                                        JOBMONITORHOST,JOBMONITORPORT, \
                                        PROBEMONITORHOST,PROBEMONITORPORT, \
                                        TUNNELMONITORHOST,TUNNELMONITORPORT, \
+                                       CLOUDMONITORHOST,CLOUDMONITORPORT, \
                                        ALLOWEDVENUEMECHANISMS)
    __jobDistributor__.setEnvironment(PBS_ROOT,CONDOR_ROOT,CONDOR_CONFIG,RUNJOB_ROOT)
    __jobDistributor__.getEnvironment()
@@ -123,3 +122,4 @@ if __name__ == '__main__':
    __jobDistributor__.reportExitCondition()
    sys.exit(__exitCode__)
 
+
